﻿#include <iostream>
#include <string>
#include <algorithm>
#include <stack>
#include <map>
#include <set>
#include <cstdio>
#include <vector>
#include <cmath>
#include <queue>
#include <numeric>
#include <climits>
#include <random>
#include <fstream>
#include <cstdlib>
#include <bitset>
#include <deque>
#include <iterator>

using namespace std;

template <typename T> inline T getint() {
	T val = 0;
	char c;
	bool neg = false;
	while ((c = getchar()) && !(c >= '0' && c <= '9')) {
		neg |= c == '-';
	}
	do {
		val = (val * 10) + c - '0';
	} while ((c = getchar()) && (c >= '0' && c <= '9'));
	return val * (neg ? -1 : 1);
}

#define int long long
#define x first
#define y second
typedef long long ll;
typedef long double ld;
const ll INF = LLONG_MAX;

ll gcd(ll a, ll b) {
	return b ? gcd(b, a % b) : a;
}

const ll maxn = 1e5;
const ld eps = 1e-10;


int intersertions(int a1, int b1, int c1, int a2, int b2, int c2) {
	int a = a1 - a2;
	int b = b1 - b2;
	int c = c1 - c2;
	if (a == 0) {
		if (b == 0) {
			return -1 * (int)(c == 0);
		}
		else
			return 1;
	}
	else {
		int D = b * b - 4 * a * c;
		if (D > 0) {
			return 2;
		}
		if (D == 0)
			return 1;
		return 0;
	}
}

pair<double, double> roots(int a1, int b1, int c1, int a2, int b2, int c2) {
	int a = a1 - a2;
	int b = b1 - b2;
	int c = c1 - c2;
	double sDd2a = sqrt(b * b - 4.0 * a * c) / 2 / a;
	if (a > 0)
		return { -b / 2 / a - sDd2a, -b / 2 / a + sDd2a };
	else
		return { -b / 2 / a + sDd2a, -b / 2 / a - sDd2a };
}

pair<double, double> roots_d(double a1, double b1, double c1, double a2, double b2, double c2) {
	double a = a1 - a2;
	double b = b1 - b2;
	double c = c1 - c2;
	double sDd2a = sqrt(b * b - 4 * a * c) / 2 / a;
	if (a > 0)
		return { -b / 2 / a - sDd2a, -b / 2 / a + sDd2a };
	else
		return { -b / 2 / a + sDd2a, -b / 2 / a - sDd2a };
}

double value(int a, int b, int c, double x) {
	return a * x * x + b * x + c;
}

pair <double, double> intersections_line(int a, int b, int c, double x1, double y1, double x2, double y2) {
	double k = (y2 - y1) / (x2 - x1);
	return roots_d(a, b, c, 0, k, y1 - k * x1);
}

double yv(int a, int b, int c) {
	return value(a, b, c, -b / 2.0 / a);
}

signed main() {
	std::ios::sync_with_stdio(false);
	std::ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	cout.setf(ios::fixed);
	cout.precision(12);
	ll n; cin >> n;
	vector<ll> a(n), b(n), c(n);
	for (ll i = 0; i < n; i++)
	{
		cin >> a[i] >> b[i] >> c[i];
	}
	bool is_inf = true;
	double x1, x2, y1, y2;
	int best_a = a[0], best_b = b[0], best_c = c[0];
	int index = 1;
	while (is_inf && index < n)
	{
		if (intersertions(best_a, best_b, best_c, a[index], b[index], c[index]) < 2) {
			if (abs(best_a) > abs(a[index])) {
				best_a = a[index];
				best_b = b[index];
				best_c = c[index];
			}
			if (best_a == a[index]) {
				if (best_a * yv(best_a, best_b, best_c) < best_a * yv(a[index], b[index], c[index])) {
					best_a = a[index];
					best_b = b[index];
					best_c = c[index];
				}
			}
		}
		else {
			is_inf = false;
			pair <double, double> rts = roots(best_a, best_b, best_c, a[index], b[index], c[index]);
			x1 = rts.first;
			x2 = rts.second;
			y1 = value(best_a, best_b, best_c, x1);
			y2 = value(best_a, best_b, best_c, x2);
		}
		index++;
	}
	if (is_inf) {
		if (best_a > 0)
			cout << 0 << " " << best_c + 1;
		else
			cout << 0 << " " << best_c - 1;
	}
	else {
		for (int i = index; i < n; i++)
		{
			double kk = (y2 - y1) / (x2 - x1);
			double bb = y1 - kk * x1;
			pair <double, double> rts = intersections_line(a[i], b[i], c[i], x1, y1, x2, y2);
			x1 = max(x1, rts.first);
			x2 = min(x2, rts.second);
			y1 = kk * x1 + bb;
			y2 = kk * x2 + bb;
		}
		cout << (x1 + x2) / 2 << " " << (y1 + y2) / 2;
	}
}