#include <iostream>
#include <random>
#include <vector>
#include <set>
#include <map>
#include <unordered_map>
#include <unordered_set>
#include <algorithm>
#include <numeric>
#include <chrono>
#include <cassert>
#include <cmath>

using namespace std;

#define sz(x) (int)(x).size()
#define all(x) (x).begin(), (x).end()
#define rall(x) (x).rbegin(), (x).rend()

#define int long long
using ll = long long;
const int INF = 0x3f3f3f3f;
using ld = long double;

mt19937 rnd(chrono::steady_clock::now().time_since_epoch().count());

class SegmentTree {
private:
    struct node {
        int sum, mini, maxi, l, r, pushed;

        node() : sum(0), mini(INF), maxi(-INF), l(-1), r(-1), pushed(INF) {}
        node(int sum, int mini, int maxi, int l, int r) : sum(sum), mini(mini), maxi(maxi), l(l), r(r), pushed(INF) {}

        node operator+(const node &n) const {
            return {sum + n.sum, min(mini, n.mini), max(maxi, n.maxi), l, n.r};
        }
    };

    std::vector<node> tree;
public:
    SegmentTree() {}

    void rebuild(int sz) {
        tree.clear();
        tree.resize(4 * sz);
        build(1, 0, sz - 1);
    }

    void build(int v, int l, int r) {
        if (l == r) {
            tree[v] = node();
            tree[v].l = l, tree[v].r = r;
            return;
        }
        int mid = (l + r) / 2;
        build(2 * v, l, mid);
        build(2 * v + 1, mid + 1, r);
        tree[v] = tree[2 * v] + tree[2 * v + 1];
    }

    void makePush(int v) {
        if (tree[v].pushed == INF) return;

        tree[v].mini = tree[v].maxi = tree[v].pushed;
        tree[v].sum = tree[v].pushed * (tree[v].r - tree[v].l + 1);
        if (tree[v].l != tree[v].r) {
            tree[2 * v].pushed = tree[v].pushed;
            tree[2 * v + 1].pushed = tree[v].pushed;
        }
        tree[v].pushed = INF;
    }

    node get(int v, int l, int r) {
        if (r < l) return node();
        makePush(v);
        if (tree[v].r < l || r < tree[v].l) return node();
        if (l <= tree[v].l && tree[v].r <= r) return tree[v];
        return get(2 * v, l, r) + get(2 * v + 1, l, r);
    }

    void upd(int v, int l, int r, int val) {
        if (r < l) return;
        makePush(v);
        if (tree[v].r < l || r < tree[v].l) return;
        if (l <= tree[v].l && tree[v].r <= r) {
            tree[v].pushed = val;
            makePush(v);
            return;
        }
        upd(2 * v, l, r, val);
        upd(2 * v + 1, l, r, val);
        tree[v] = tree[2 * v] + tree[2 * v + 1];
    }
};

void solve() {
    int n, k;
    std::cin >> n >> k;
    vector<int> a(n), b(n), c(n);
    for (int i = 0; i < n; i++) {
        std::cin >> a[i] >> b[i];
        if (a[i] < b[i]) swap(a[i], b[i]);
        c[i] = a[i] - b[i];
    }

    vector<int> pref(n);
    for (int i = 0; i < n; i++) {
        pref[i] = (i > 0 ? pref[i - 1] : 0) + a[i];
    }

    std::map<int, int> cnt;
    for (int i = 0; i < n; i++) {
        cnt[pref[i] % k]++;
    }

    auto get = [&](int l, int r) {
        return pref[r] - (l == 0 ? 0 : pref[l - 1]);
    };

    std::map<int, SegmentTree> sts;
    for (auto &i : cnt) {
        sts[i.first].rebuild(i.second);
    }
    map<int, int> last;
    cnt.clear();

    ll ans = 0;
    for (int i = 0; i < n; i++) {
        for (int j = i; j < n; j++) {
            ans += pref[j] - (i == 0 ? 0 : pref[i - 1]);
        }
    }

    for (int i = 0; i < n; i++) {
        int bucket = pref[i] % k;
        int l = last[bucket];
        int mini = *std::min_element(c.begin() + l, c.begin() + i + 1);

        int left = -1, right = cnt[bucket];
        while (right - left > 1) {
            int mid = (left + right) / 2;
            if (sts[bucket].get(1, mid, right).mini > mini) {
                right = mid;
            } else {
                left = mid;
            }
        }
        sts[bucket].upd(1, right, cnt[bucket], mini);
        ans -= sts[bucket].get(1, 0, cnt[bucket] - 1).sum;

        cnt[bucket]++;
    }

    std::cout << ans << '\n';
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    solve();
//    int t; cin >> t; while(t--) solve();
}
