#include <iostream>
#include <vector>
#include <cassert>
#include <algorithm>
#include <cmath>
#include <random>
using namespace std;
using ll = long long;
using ld = double;

const ld EPS = 1e-4;
const ld INF = 1e18;

struct poly2 {
    ll a, b, c;

    poly2() {}

    poly2(ll a_, ll b_, ll c_): a(a_), b(b_), c(c_) {}

    ld atx(ld x) {
        return a * x * x + b * x + c;
    }

    pair<ld, ld> aty(ld y) {
        ld D = b * b - 4 * a * (c - y);
        if (D < 0)
            return {177013, 177013};
        ld x1 = (-b - sqrt(D)) / a / 2;
        ld x2 = (-b + sqrt(D)) / a / 2;
        if (a < 0)
            swap(x1, x2);
        return {x1, x2};
    }

    poly2 operator+(const poly2 p) const {
        return {a + p.a, b + p.b, c + p.c};
    }

    poly2 operator-() const {
        return {-a, -b, -c};
    }

    poly2 operator-(const poly2 p) const {
        return {a - p.a, b - p.b, c - p.c};
    }


    bool in(ld x, ld y) {
        return (a > 0 && y + EPS >= atx(x)) || (a < 0 && y - EPS <= atx(x));
    }

    pair<ld, ld> intersect(poly2 p) {
        if (a == p.a)
            return {177013, 177013};
        poly2 dif = *this - p;
        auto [x1, x2] = dif.aty(0);
        return {x1, x2};
    }
};

pair<ld, ld> highest(poly2 p1, poly2 p2) {
    if (p1.a > 0)
        swap(p1, p2);
    auto [x1, x2] = p1.intersect(p2);
    ld x0 = 1.0 * p1.b / 2 / p1.a;
    if (x1 <= x0 && x0 <= x2) {
        return {x0, p1.atx(x0)};
    } else if (p1.atx(x1) <= p1.atx(x2)) {
        return {x2, p1.atx(x2)};
    } else {
        return {x1, p1.atx(x1)};
    }
}

const int MAXN = 1e5 + 123;
poly2 a[MAXN];

pair<ld, ld> intersect(pair<ld, ld> p1, pair<ld, ld> p2) {
    return {max(p1.first, p2.first), min(p1.second, p2.second)};
}

vector<pair<ld, ld>> unite(vector<pair<ld, ld>> v0) {
    vector<pair<ld, int>> events;
    for (auto [l, r] : v0) {
        events.push_back({l, 1});
        events.push_back({r, -1});
    }
    vector<pair<ld, ld>> ans;
    sort(events.begin(), events.end());
    int sm = 0;
    ld l = 0;
    for (auto [x, e]: events) {
        if (sm == 0) {
            l = x;
        }
        sm += e;
        if (sm == 0) {
            ans.push_back({l, x});
        }
    }
    return ans;
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    // freopen("tst", "r", stdin);
    int n;
    cin >> n;
    bool ispos = false;
    bool isneg = false;
    vector<poly2> pos;
    vector<poly2> neg;
    for (int i = 0; i < n; ++i) {
        cin >> a[i].a >> a[i].b >> a[i].c;
    }
    ld x = 0;
    ld y = 1000000008;
    if (a[0].a < 0)
        y *= -1;
    for (int i = 0; i < n; ++i) {
        if (!a[i].in(x, y)) {
            pair<ld, ld> p0 = {-INF, INF};
            vector<pair<ld, ld>> v;

            for (int j = 0; j < i; ++j) {
                pair<ld, ld> pp = a[i].intersect(a[j]);
                if (a[i].a == a[j].a) {
                    if (a[i].b != a[j].b) {
                        ld xxx = (a[i].c - a[j].c) / (a[j].b - a[i].b);
                        ld yyy = a[i].atx(xxx + 1);
                        if (a[j].in(xxx + 1, yyy)) {
                            p0 = intersect(p0, {xxx, INF});
                        } else {
                            p0 = intersect(p0, {-INF, xxx});
                        }
                    }
                    continue;
                }
                if (a[i].a * a[j].a < 0 || abs(a[i].a) < abs(a[j].a)) {
                    if (pp.first == 177013)
                        pp = {-INF, INF};
                    p0 = intersect(p0, pp);
                } else {
                    if (pp.first == 177013)
                        pp = {0, 0};
                    v.push_back(pp);
                }
            }
            // cout << "(" << p0.first << ' ' << p0.second << "): ";
            // for (auto ppp : v) {
            //     cout << "(" << ppp.first << ' ' << ppp.second << ") ";
            // }
            // cout << endl;
            v = unite(v);
            bool isok = false;
            if (v.empty() || p0.first <= v[0].first) {
                x = p0.first;
                isok = true;
            } else {
                if (p0.second >= v.back().second) {
                    x = p0.second;
                    isok = true;
                } else {
                    for (int i = 0; i + 1 < v.size(); ++i) {
                        pair<ld, ld> pp = {v[i].second, v[i + 1].first};
                        pair<ld, ld> p = intersect(p0, pp);
                        if (p.first <= p.second) {
                            x = p.first;
                            isok = true;
                            break;
                        }
                    }
                }
            }
            assert(isok);
            y = a[i].atx(x);
            // for (int j = 0; j < i; ++j) {
            //     pair<ld, ld> pp = a[i].intersect(a[j]);
            //     if (a[i].a * a[j].a < 0 || abs(a[i].a) < abs(a[j].a)) {
            //         assert(pp.first <= x && x <= pp.second);
            //     } else {
            //         assert(pp.first >= x || x >= pp.second);
            //     }
            //     assert(a[j].in(x, y));
            // }
        }
    }
    // for (int j = 0; j < n; ++j) {
    //     assert(a[j].in(x, y));
    // }
    printf("%.20f %.20f\n", x, y);
}
